@@ -42,7 +42,6 @@
 
 #include <Lum/OS/Theme.h>
 
-#include "Configuration.h"
 #include "Trend.h"
 #include "Util.h"
 
@@ -187,49 +186,49 @@ public:
   }
 };
 
-class FoodsEntry : public Lum::Model::ListTable::Entry
+class FoodDataProvider : public FoodModel::DataProvider
 {
 public:
-  const ::Food *entry;
+  std::wstring GetString(const FoodModel::Iterator& iter, size_t column) const
+  {
+    switch (column) {
+    case 1:
+      return (*iter)->name+L" ("+(*iter)->unit+L")";
+    case 2:
+      return ValueToString((*iter)->value)+L" "+valueUnit->Get();
+    default:
+      return L"";
+    }
+  }
+};
 
+class FoodComparator : public FoodModel::Comparator
+{
 public:
-  FoodsEntry(Lum::Model::ListTable *table,
-             const ::Food* entry)
-  : Lum::Model::ListTable::Entry(table),
-    entry(entry)
+  bool operator()(const FoodModel::ElementType& a,
+                  const FoodModel::ElementType& b,
+                  size_t column, bool down) const
   {
-    // no code
-  }
-
-  std::wstring GetString(size_t column) const
-  {
-    if (column==1) {
-      return entry->name+L" ("+entry->unit+L")";
+    if (down) {
+      return a->name>b->name;
     }
-    else if (column==2) {
-      return ValueToString(entry->value)+L" "+valueUnit->Get();
+    else {
+      return a->name<b->name;
     }
-
-    assert(false);
-  }
-
-  bool IsGreater(const Entry* other, size_t column)
-  {
-    return entry->name>dynamic_cast<const FoodsEntry*>(other)->entry->name;
   }
 };
 
 class FoodFormatProvider : public Lum::TableView::FormatProvider
 {
 private:
-  Lum::Model::ListTable *table;
-  Lum::OS::ColorRef     goodFoodColor;
-  Lum::OS::ColorRef     badFoodColor;
-  Lum::OS::FillRef      goodFoodBackground;
-  Lum::OS::FillRef      badFoodBackground;
+  FoodModelRef      table;
+  Lum::OS::ColorRef goodFoodColor;
+  Lum::OS::ColorRef badFoodColor;
+  Lum::OS::FillRef  goodFoodBackground;
+  Lum::OS::FillRef  badFoodBackground;
 
 public:
-  FoodFormatProvider(Lum::Model::ListTable* table)
+  FoodFormatProvider(FoodModel* table)
    : table(table),
      goodFoodColor(0.82,1.0,0.82,Lum::OS::display->GetColor(Lum::OS::Display::whiteColor)),
      badFoodColor(1.0,0.82,0.82,Lum::OS::display->GetColor(Lum::OS::Display::whiteColor)),
@@ -241,12 +240,12 @@ public:
 
   Lum::OS::Fill* GetBackground(size_t column, size_t row) const
   {
-    FoodsEntry* entry=(FoodsEntry*)table->GetEntry(row);
+    const Food* entry=table->GetEntry(row);
 
-    if (entry->entry->value<=(Value)goodValueLimit->Get()) {
+    if (entry->value<=(Value)goodValueLimit->Get()) {
       return goodFoodBackground.Get();
     }
-    else if (entry->entry->value>=(Value)badValueLimit->Get()) {
+    else if (entry->value>=(Value)badValueLimit->Get()) {
       return badFoodBackground.Get();
     }
     else {
@@ -256,20 +255,18 @@ public:
 };
 
 FoodInput::FoodInput()
- : clearFilterAction(new Lum::Model::Action()),
-   addFoodEntryAction(new Lum::Model::Action()),
+ : addFoodEntryAction(new Lum::Model::Action()),
    removeFoodEntryAction(new Lum::Model::Action()),
    editFoodEntryAction(new Lum::Model::Action()),
    registerFoodAction(new Lum::Model::Action()),
 
    foodSearch(new Lum::Model::String(L"")),
-   foods(new Lum::Model::ListTable()),
+   foods(new FoodModel(new FoodDataProvider(),new FoodComparator())),
    foodSelection(new Lum::Model::SingleLineSelection()),
 
    searchTimerAction(new Lum::Model::Action())
 {
   Observe(foodSearch);
-  Observe(clearFilterAction);
 
   Observe(addFoodEntryAction);
   Observe(removeFoodEntryAction);
@@ -300,8 +297,7 @@ void FoodInput::CalcSize()
   sb->Add(Lum::HPanel::Create(true,false)
           ->Add(Lum::Text::Create(L"Search:"))
           ->AddSpace()
-          ->Add(Lum::String::Create(foodSearch,true,false))
-          ->Add(Lum::Button::Create(L"_Clear",clearFilterAction,false,true))
+          ->Add(Lum::String::Create(foodSearch,true,false)->ShowClearButton(true))
           ->AddSpace()
           ->Add(Lum::Button::Create(L"+",
                                     Lum::OS::Theme::imageAdd,
@@ -384,7 +380,7 @@ void FoodInput::UpdateFoods()
   foods->Clear();
   for (std::set<Food>::iterator iter=data.foods.begin(); iter!=data.foods.end(); ++iter) {
     if (filter.empty()) {
-      foods->Append(new FoodsEntry(foods,&*iter));
+      foods->Append(&*iter);
     }
     else {
       std::wstring tmp(iter->name);
@@ -392,7 +388,7 @@ void FoodInput::UpdateFoods()
       Lum::Base::ToLower(tmp);
 
       if (tmp.find(filter)!=std::wstring::npos) {
-        foods->Append(new FoodsEntry(foods,&*iter));
+        foods->Append(&*iter);
       }
     }
   }
@@ -454,7 +450,7 @@ void FoodInput::AddFoodEntry()
     return;
   }
 
-  foods->Append(new FoodsEntry(foods,result));
+  foods->Append(result);
 
   foods->Sort(1);
 }
@@ -462,18 +458,18 @@ void FoodInput::AddFoodEntry()
 void FoodInput::EditFoodEntry()
 {
   Food       oldFood;
-  FoodsEntry *entry=(FoodsEntry*)foods->GetEntry(foodSelection->GetLine());
+  const Food *entry=foods->GetEntry(foodSelection->GetLine());
 
   Lum::Model::StringRef name;
   Lum::Model::StringRef unit;
   Lum::Model::StringRef value;
   Value                 v;
 
-  oldFood=*entry->entry;
+  oldFood=*entry;
 
-  name=new Lum::Model::String(entry->entry->name);
-  unit=new Lum::Model::String(entry->entry->unit);
-  value=new Lum::Model::String(ValueToString(entry->entry->value));
+  name=new Lum::Model::String(entry->name);
+  unit=new Lum::Model::String(entry->unit);
+  value=new Lum::Model::String(ValueToString(entry->value));
 
   if (!FoodEdit::EditFood(this->GetWindow(),
                               L"Editing food component...",
@@ -494,7 +490,7 @@ void FoodInput::EditFoodEntry()
 
   foods->Off();
 
-  data.DeleteFood(*dynamic_cast<FoodsEntry*>(foods->GetEntry(foodSelection->GetLine()))->entry);
+  data.DeleteFood(*foods->GetEntry(foodSelection->GetLine()));
   foods->Delete(foodSelection->GetLine());
 
   Food       food;
@@ -519,7 +515,7 @@ void FoodInput::EditFoodEntry()
     result=data.AddFood(oldFood);
   }
 
-  foods->Append(new FoodsEntry(foods,result));
+  foods->Append(result);
   foods->Sort(1);
 
   foods->On();
@@ -527,13 +523,13 @@ void FoodInput::EditFoodEntry()
 
 void FoodInput::RemoveFoodEntry()
 {
-  data.DeleteFood(*dynamic_cast<FoodsEntry*>(foods->GetEntry(foodSelection->GetLine()))->entry);
+  data.DeleteFood(*foods->GetEntry(foodSelection->GetLine()));
   foods->Delete(foodSelection->GetLine());
 }
 
 void FoodInput::RegisterFood()
 {
-  FoodsEntry *entry=(FoodsEntry*)foods->GetEntry(foodSelection->GetLine());
+  const Food *entry=foods->GetEntry(foodSelection->GetLine());
 
   Lum::Model::StringRef value;
   size_t                amount;
@@ -542,11 +538,11 @@ void FoodInput::RegisterFood()
   value=new Lum::Model::String(L"1");
 
   t1=_(L"FOOD_REGISTER_TITLE",L"I have consumed $food...");
-  Lum::Base::L10N::Substitute(t1,L"$food",entry->entry->name);
+  Lum::Base::L10N::Substitute(t1,L"$food",entry->name);
   t2=_(L"FOOD_REGISTER_TEXT",L"Please enter the amount of $food\nyou have consumed!");
-  Lum::Base::L10N::Substitute(t2,L"$food",entry->entry->name);
+  Lum::Base::L10N::Substitute(t2,L"$food",entry->name);
   if (!FoodRegister::RegisterFood(this->GetWindow(),
-                                  t1,t2,timestamp,value,entry->entry->unit)) {
+                                  t1,t2,timestamp,value,entry->unit)) {
     return;
   }
 
@@ -561,9 +557,9 @@ void FoodInput::RegisterFood()
   Entry e;
 
   e.time=timestamp->Get();
-  e.item=entry->entry->name;
-  e.unit=entry->entry->unit;
-  e.value=entry->entry->value;
+  e.item=entry->name;
+  e.unit=entry->unit;
+  e.value=entry->value;
   e.amount=amount;
 
   data.AddEntry(date->Get(),e);
@@ -573,12 +569,7 @@ void FoodInput::RegisterFood()
 
 void FoodInput::Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg)
 {
-  if (model==clearFilterAction && clearFilterAction->IsFinished()) {
-    lastFoodSearchFilter=foodSearch->Get();
-    foodSearch->Set(L"");
-    UpdateFoods();
-  }
-  else if (model==addFoodEntryAction && addFoodEntryAction->IsFinished()) {
+  if (model==addFoodEntryAction && addFoodEntryAction->IsFinished()) {
     AddFoodEntry();
   }
   else if (model==editFoodEntryAction && editFoodEntryAction->IsFinished()) {
@@ -600,8 +591,14 @@ void FoodInput::Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg)
     UpdateFoods();
   }
   else if (model==foodSearch) {
-    Lum::OS::display->RemoveTimer(searchTimerAction);
-    Lum::OS::display->AddTimer(1,500000,searchTimerAction);
+    if (foodSearch->Empty()) {
+      UpdateFoods();
+      lastFoodSearchFilter=foodSearch->Get();
+    }
+    else {
+      Lum::OS::display->RemoveTimer(searchTimerAction);
+      Lum::OS::display->AddTimer(1,150000,searchTimerAction);
+    }
   }
   else if (model==searchTimerAction && searchTimerAction->IsFinished()) {
     if (foodSearch->Get()!=lastFoodSearchFilter) {
