@@ -28,17 +28,21 @@
 #include <Lum/Model/Table.h>
 #include <Lum/Model/Time.h>
 
+#include "Configuration.h"
+
+typedef Lum::Model::StdTable<const Food*> FoodModel;
+typedef Lum::Base::Reference<FoodModel>   FoodModelRef;
+
 class FoodInput : public Lum::Component
 {
 private:
-  Lum::Model::ActionRef              clearFilterAction;
   Lum::Model::ActionRef              addFoodEntryAction;
   Lum::Model::ActionRef              removeFoodEntryAction;
   Lum::Model::ActionRef              editFoodEntryAction;
   Lum::Model::ActionRef              registerFoodAction;
 
   Lum::Model::StringRef              foodSearch;
-  Lum::Model::ListTableRef           foods;
+  FoodModelRef                       foods;
   Lum::Model::SingleLineSelectionRef foodSelection;
   std::wstring                       lastFoodSearchFilter;
   Lum::Model::ActionRef              searchTimerAction;
