@@ -21,6 +21,9 @@
 #include <Lum/Base/Path.h>
 #include <Lum/Base/String.h>
 
+#include <Lum/Def/Menu.h>
+#include <Lum/Def/MultiView.h>
+
 #include <Lum/Dialog.h>
 #include <Lum/Menu.h>
 #include <Lum/Panel.h>
@@ -90,53 +93,58 @@ public:
 
   void PreInit()
   {
-    Lum::Panel *panel;
-    Lum::Tab   *tab;
+    Lum::Def::MultiView multiView(Lum::Def::Desc(L"WeightJinni"));
 
-    panel=Lum::VPanel::Create(true,true);
-
-    tab=Lum::Tab::Create(true,true);
-    tab->SetModel(currentTab);
+    multiView.SetValue(currentTab);
 
     foodInput=new FoodInput();
     foodInput->SetFlex(true,true);
 
-    tab->Add(_(L"MAIN_TAB_FOODINPUT",L"Food"),foodInput);
+    multiView.AddView(Lum::Def::MultiView::View(0,
+                                                Lum::Def::Desc(_(L"MAIN_TAB_FOODINPUT",L"Food")),
+                                                foodInput));
 
     dataInput=new DataInput();
     dataInput->SetFlex(true,true);
 
-    tab->Add(_(L"MAIN_TAB_INPUT",L"Day view"),dataInput);
+    multiView.AddView(Lum::Def::MultiView::View(1,
+                                                Lum::Def::Desc(_(L"MAIN_TAB_INPUT",L"Day view")),
+                                                dataInput));
 
     diagram=new Diagram();
     diagram->SetFlex(true,true);
 
-    tab->Add(_(L"MAIN_TAB_DIAGRAM",L"Diagram"),Lum::View::Create(diagram,true,true));
+    multiView.AddView(Lum::Def::MultiView::View(2,
+                                                Lum::Def::Desc(_(L"MAIN_TAB_DIAGRAM",L"Diagram")),
+                                                Lum::View::Create(diagram,true,true)));
 
-    panel->Add(tab);
+    Lum::OS::display->GetBehaviour()->ApplyMultiViewDlg(this,multiView);
 
-    SetMain(panel);
-
-    Lum::MenuDesc *menu=new Lum::MenuDesc();
+    Lum::Def::Menu *menu=Lum::Def::Menu::Create();
 
     menu
-      ->AddMenuItemSub(_ld(menuProject))
-        ->AddMenuItemAction(_(L"MENU_IMPORT_FOOD_COMPONENTS",L"_Import food components..."),Lum::OS::qualifierControl,L"i",importAction)
-        ->AddMenuItemAction(_(L"MENU_EXPORT_FOOD_COMPONENTS",L"_Export food components..."),Lum::OS::qualifierControl,L"e",exportAction)
-        ->AddSeparator()
-        ->AddMenuItemAction(_(L"MENU_BACKUP",L"_Backup..."),backupAction)
-        ->AddMenuItemAction(_(L"MENU_RESTORE",L"_Restore..."),restoreAction)
-        ->AddSeparator()
-        ->AddMenuItemAction(_ld(menuProjectQuit),Lum::OS::qualifierControl,L"q",GetClosedAction());
-    menu
-      ->AddMenuItemSub(_ld(menuEdit))
-        ->AddMenuItemAction(_(L"MENU_STATISTICS",L"_Statistics..."),statisticsAction)
-        ->AddSeparator()
-        ->AddMenuItemAction(_ld(menuEditSettings),Lum::OS::qualifierControl,L"p",configAction);
-    menu
-      ->AddMenuItemSub(_ld(menuHelp))
-        ->AddMenuItemAction(_ld(menuHelpHelp),helpAction)
-        ->AddMenuItemAction(_ld(menuHelpAbout),aboutAction);
+      ->GroupProject()
+        ->Action(Lum::Def::Action(Lum::Def::Desc(_(L"MENU_IMPORT_FOOD_COMPONENTS",L"_Import food..."))
+                                  .SetShortcut(Lum::OS::qualifierControl,L"i"),
+                                  importAction))
+        ->Action(Lum::Def::Action(Lum::Def::Desc(_(L"MENU_EXPORT_FOOD_COMPONENTS",L"_Export food..."))
+                                  .SetShortcut(Lum::OS::qualifierControl,L"e"),
+                                  exportAction))
+        ->Separator()
+        ->Action(Lum::Def::Action(Lum::Def::Desc(_(L"MENU_BACKUP",L"_Backup...")),backupAction))
+        ->Action(Lum::Def::Action(Lum::Def::Desc(_(L"MENU_RESTORE",L"_Restore...")),restoreAction))
+        ->Separator()
+        ->ActionQuit(GetClosedAction())
+      ->End()
+      ->GroupEdit()
+        ->Action(Lum::Def::Action(Lum::Def::Desc(_(L"MENU_STATISTICS",L"_Statistics...")),statisticsAction))
+        ->Separator()
+        ->ActionSettings(configAction)
+      ->End()
+      ->GroupHelp()
+        ->ActionHelp(helpAction)
+        ->ActionAbout(aboutAction)
+      ->End();
 
     SetMenu(menu);
 
