@@ -17,12 +17,11 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */
 
-#include <Lum/Dialog.h>
+#include <Lum/Dlg/ActionDialog.h>
 
-#include <Lum/Model/Action.h>
 #include <Lum/Model/String.h>
 
-class Preferences : public Lum::Dialog
+class Preferences : public Lum::Dlg::ActionDialog
 {
 private:
   Lum::Model::ActionRef okAction;
@@ -48,7 +47,8 @@ public:
   Preferences();
   ~Preferences();
 
-  void PreInit();
+  Lum::Object* GetContent();
+  void GetActions(std::vector<Lum::Dlg::ActionInfo>& actions);
 
   void Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg);
 };
